==> aoe2netwrapper-0.3.1.tar.gz: aoe2netwrapper-0.3.1/README.md <==
<h1 align="center">
  <b>aoe2netwrapper</b>
</h1>

<p align="center">
  <!-- PyPi Version -->
  <a href="https://pypi.org/project/aoe2netwrapper">
    <img alt="PyPI Version" src="https://img.shields.io/pypi/v/aoe2netwrapper?label=PyPI&logo=PyPI">
  </a>

  <!-- Github Release -->
  <a href="https://github.com/fsoubelet/AoE2NetAPIWrapper/releases">
    <img alt="Github Release" src="https://img.shields.io/github/v/release/fsoubelet/AoE2NetAPIWrapper?color=orange&label=Release&logo=Github">
  </a>

  <br/>

  <!-- Github Actions Build -->
  <a href="https://github.com/fsoubelet/AoE2NetAPIWrapper/actions?query=workflow%3A%22Tests%22">
    <img alt="Github Actions" src="https://github.com/fsoubelet/AoE2NetAPIWrapper/workflows/Tests/badge.svg?branch=master">
  </a>

  <!-- Code Coverage -->
  <a href="https://codeclimate.com/github/fsoubelet/AoE2NetAPIWrapper/maintainability">
    <img alt="Code Coverage" src="https://img.shields.io/codeclimate/maintainability/fsoubelet/AoE2NetAPIWrapper?label=Maintainability&logo=Code%20Climate">
  </a>

  <br/>

  <!-- Code style -->
  <a href="https://github.com/psf/Black">
    <img alt="Code Style" src="https://img.shields.io/badge/Code%20Style-Black-9cf.svg">
  </a>

  <!-- Linter -->
  <a href="https://github.com/PyCQA/pylint">
    <img alt="Linter" src="https://img.shields.io/badge/Linter-Pylint-ce963f.svg">
  </a>

  <!-- Build tool -->
  <a href="https://github.com/python-poetry/poetry">
    <img alt="Build tool" src="https://img.shields.io/badge/Build%20Tool-Poetry-4e5dc8.svg">
  </a>

  <!-- Test runner -->
  <a href="https://github.com/pytest-dev/pytest">
    <img alt="Test runner" src="https://img.shields.io/badge/Test%20Runner-Pytest-ce963f.svg">
  </a>

  <!-- License -->
  <a href="https://github.com/fsoubelet/AoE2NetAPIWrapper/blob/master/LICENSE">
    <img alt="License" src="https://img.shields.io/github/license/fsoubelet/AoE2NetAPIWrapper?color=9cf&label=License">
  </a>
</p>

<p align="center">
  A simple, efficient and typed wrapper to query the https://aoe2.net APIs with Python 3.6.1+
</p>

<p align="center">
  <a href="https://www.python.org/">
    <img alt="Made With Python" src="https://forthebadge.com/images/badges/made-with-python.svg">
  </a>
</p>

Link to [documentation][package_doc].

Link to [source code][package_source].

## License

Copyright &copy; 2021 Felix Soubelet. [MIT License](LICENSE)

[package_doc]: https://fsoubelet.github.io/AoE2NetAPIWrapper/
[package_source]: https://github.com/fsoubelet/AoE2NetAPIWrapper

==> aoe2netwrapper-0.4.0.tar.gz: aoe2netwrapper-0.4.0/README.md <==
<h1 align="center">
  <b>aoe2netwrapper</b>
</h1>

<p align="center">
  <!-- PyPi Version -->
  <a href="https://pypi.org/project/aoe2netwrapper">
    <img alt="PyPI Version" src="https://img.shields.io/pypi/v/aoe2netwrapper?label=PyPI&logo=PyPI">
  </a>

  <!-- Github Release -->
  <a href="https://github.com/fsoubelet/AoE2NetAPIWrapper/releases">
    <img alt="Github Release" src="https://img.shields.io/github/v/release/fsoubelet/AoE2NetAPIWrapper?color=orange&label=Release&logo=Github">
  </a>

  <br/>

  <!-- Github Actions Build -->
  <a href="https://github.com/fsoubelet/AoE2NetAPIWrapper/actions?query=workflow%3A%22Cron+Testing%22">
    <img alt="Github Actions" src="https://github.com/fsoubelet/AoE2NetAPIWrapper/workflows/Tests/badge.svg">
  </a>

  <!-- Code Coverage -->
  <a href="https://codeclimate.com/github/fsoubelet/AoE2NetAPIWrapper/maintainability">
    <img alt="Code Coverage" src="https://img.shields.io/codeclimate/maintainability/fsoubelet/AoE2NetAPIWrapper?label=Maintainability&logo=Code%20Climate">
  </a>

  <br/>
  <!-- Code style -->
  <a href="https://github.com/psf/Black">
    <img alt="Code Style" src="https://img.shields.io/badge/Code%20Style-Black-9cf.svg">
  </a>

  <!-- Linter -->
  <a href="https://github.com/astral-sh/ruff">
    <img alt="Linter" src="https://img.shields.io/badge/Linter-Ruff-ce963f.svg">
  </a>

  <!-- Build tool -->
  <a href="https://github.com/pypa/hatch">
    <img alt="Build tool" src="https://img.shields.io/badge/Build%20Tool-Hatch-4e5dc8.svg">
  </a>

  <!-- Test runner -->
  <a href="https://github.com/pytest-dev/pytest">
    <img alt="Test runner" src="https://img.shields.io/badge/Test%20Runner-Pytest-ce963f.svg">
  </a>

  <!-- License -->
  <a href="https://github.com/fsoubelet/AoE2NetAPIWrapper/blob/master/LICENSE">
    <img alt="License" src="https://img.shields.io/github/license/fsoubelet/AoE2NetAPIWrapper?color=9cf&label=License">
  </a>
</p>

<p align="center">
  A simple, efficient and typed Python wrapper to query the https://aoe2.net APIs
</p>

<p align="center">
  <a href="https://www.python.org/">
    <img alt="Made With Python" src="https://forthebadge.com/images/badges/made-with-python.svg">
  </a>
</p>

Link to [documentation][package_doc].

Link to [source code][package_source].

---

<div align="center">
  <sub><strong>Made with ♥︎ by fsoubelet</strong></sub>
  <br>
  <sub><strong>MIT &copy 2021 Felix Soubelet</strong></sub>
</div>

[package_doc]: https://fsoubelet.github.io/AoE2NetAPIWrapper/
[package_source]: https://github.com/fsoubelet/AoE2NetAPIWrapper
